/******************************************************************************/
/* SISTEMAS INTEGRADOS TECNISA                                                */
/******************************************************************************/
/*                                                                            */
/* NOME: POSIO_ESTOQUE                                                      */
/* MANUTENO: CONVERSO P/ SQLSERVER                                         */
/* 20/11/2001 - ALESSANDRA CRISTINA                                           */

-- ====================================================================
--                 PROCEDIMENTO PARA POSIO DE ESTOQUE
--                 ------------ ---- ------- -- -------
--
--  PARMETROS: P_FILIAL     = CDIGO DA FILIAL A SER CONSIDERADA.          (IN)
--  ----------  P_PRODUTO    = PRODUTO A SER ATUALIZADO.                    (IN)
--              P_DTPOSICAO  = DATA INICIAL PARA CLCULO DO ESTOQUE.        (IN)
--              P_QTDEESTO   = QUANTIDADE EM ESTOQUE.                       (OUT)
--              P_VALRESTO   = VALOR DO ESTOQUE.                            (OUT)
--              P_VALRBRUT   = VALOR DO ESTOQUE (BRUTO).                    (OUT)
--              P_POSNZERO   = VERIFICA LTIMA POSIO ANTES DE ZERAR.      (IN) DEFAULT 'N'
--              P_ALMOXARIFE = CDIGO DO ALMOXARIFADO A SER CONSIDERADO.    (IN) DEFAULT NULL
--              P_LOCALESTOQ = CDIGO DO LOCAL DE ESTOQUE A SER CONSIDERADO.(IN) DEFAULT NULL
--
-- @C:\WIN_V1.52\SQL\SQLSERVER\0002_GERSTP_POSICAO_ESTOQUE.SQL
--
-- ====================================================================
IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'CONSULTA_LOTE' AND
                 TYPE = 'P' 		         AND
	              U.UID = O.UID            AND
	              U.NAME = USER)
DROP PROCEDURE CONSULTA_LOTE
GO
CREATE  PROCEDURE CONSULTA_LOTE(
                    @P_IDUTILLOTE   VARCHAR(01),
                    @P_CDFILIAL     VARCHAR(04),
                    @P_CDALMOXARIFE VARCHAR(06),
                    @P_CDLOCALESTOQ VARCHAR(06),
                    @P_CDPRODUTO    VARCHAR(10),
                    @P_NRLOTEESTQ   VARCHAR(20)OUTPUT,
                    @P_NRSUBLOTE    VARCHAR(04)OUTPUT)
AS
   DECLARE @V_LOTEESTQ     VARCHAR(20);
   DECLARE @V_SUBLOTE      VARCHAR(04);
   DECLARE @V_IDUTCTRLLOTE VARCHAR(01);
BEGIN
   SET @V_IDUTCTRLLOTE = NULL;
   SET @V_LOTEESTQ     = NULL;
   SET @V_SUBLOTE      = NULL;

   IF @P_IDUTILLOTE = 'N' BEGIN
      SET @P_NRLOTEESTQ = ' ';
      SET @P_NRSUBLOTE  = ' ';
   END
   ELSE BEGIN
      SELECT
         @V_IDUTCTRLLOTE = MAX(IDUTCTRLLOTE)
      FROM
         PRODFILI
      WHERE
         (CDFILIAL = @P_CDFILIAL) AND
         (CDPRODUTO = @P_CDPRODUTO);

      IF (@V_IDUTCTRLLOTE = 'N') OR (@V_IDUTCTRLLOTE IS NULL) BEGIN
         SET @P_NRLOTEESTQ = ' ';
         SET @P_NRSUBLOTE  = ' ';
      END
      ELSE BEGIN
         SELECT @V_LOTEESTQ = ISNULL(MIN(NRLOTEESTQ), ' ')
         FROM POSESTATU
         WHERE (CDFILIAL     = @P_CDFILIAL)     AND
               (CDALMOXARIFE = @P_CDALMOXARIFE) AND
               (CDLOCALESTOQ = @P_CDLOCALESTOQ) AND
               (CDPRODUTO    = @P_CDPRODUTO)    AND
               (QTTOTALESTOQ > 0);

         SELECT @V_SUBLOTE = ISNULL(MAX(NRSUBLOTE), ' ')
         FROM LOTE
         WHERE (CDFILIAL     = @P_CDFILIAL) AND
               (NRLOTEESTQ   = @V_LOTEESTQ);

         SET @P_NRLOTEESTQ = @V_LOTEESTQ;
         SET @P_NRSUBLOTE  = @V_SUBLOTE;
      END;
   END;
END;
GO


-- VERSAO --
EXEC ATUVEROBJ 'CONSULTA_LOTE','4.05.109';
GO

